netapp_ontap.models.cluster_space_block_storage API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.cluster_space_block_storage`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ClusterSpaceBlockStorageSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ClusterSpaceBlockStorage object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `inactive_data GET POST PATCH`

    Inactive data across all aggregates

  `medias GET POST PATCH`

    The medias field of the cluster_space_block_storage.

  `size GET POST PATCH`

    Total space across the cluster

  `used GET POST PATCH`

    Space used (includes volume reserves)